==> gtk-gnutella_0.96.6+dfsg.orig.tar.gz: gtk-gnutella-0.96.6+dfsg/src/lib/mime_types.h <==
MIME_TYPE(APPLICATION_BINARY, 		"application/binary")
MIME_TYPE(APPLICATION_BITTORRENT,	"application/x-bittorrent")
MIME_TYPE(APPLICATION_BZIP2,  		"application/x-bzip2")
MIME_TYPE(APPLICATION_DEB,		"application/x-debian-package")
MIME_TYPE(APPLICATION_DMG,		"application/x-apple-diskimage")
MIME_TYPE(APPLICATION_DOSEXEC,		"application/x-dosexec")
MIME_TYPE(APPLICATION_EXCEL,		"application/vnd.ms-excel")
MIME_TYPE(APPLICATION_GZIP,		"application/x-gzip")
MIME_TYPE(APPLICATION_ISO9660,		"application/x-iso9660-image")
MIME_TYPE(APPLICATION_JAR,		"application/x-java-archive")
MIME_TYPE(APPLICATION_JAVA,		"application/java")
MIME_TYPE(APPLICATION_JAVASCRIPT,	"application/x-javascript")
MIME_TYPE(APPLICATION_JAVA_SER,		"application/x-java-serialized-object")
MIME_TYPE(APPLICATION_JAVA_VM,		"application/x-java-vm")
MIME_TYPE(APPLICATION_LATEX,		"application/x-latex")
MIME_TYPE(APPLICATION_LYX,		"application/x-lyx")
MIME_TYPE(APPLICATION_MSWORD,		"application/msword")
MIME_TYPE(APPLICATION_OBJECT,		"application/x-object")
MIME_TYPE(APPLICATION_OCTET_STREAM, 	"application/octet-stream")
MIME_TYPE(APPLICATION_OGG,		"application/ogg")
MIME_TYPE(APPLICATION_PDF,		"application/pdf")
MIME_TYPE(APPLICATION_POSTSCRIPT,	"application/postscript")
MIME_TYPE(APPLICATION_POWERPOINT,	"application/vnd.ms-powerpoint")
MIME_TYPE(APPLICATION_RAR,		"application/x-rar")
MIME_TYPE(APPLICATION_RDF,		"application/rss+rdf")
MIME_TYPE(APPLICATION_RPM,		"application/x-redhat-package")
MIME_TYPE(APPLICATION_RSS,		"application/rss+xml")
MIME_TYPE(APPLICATION_SH,		"application/x-sh")
MIME_TYPE(APPLICATION_SHAR,		"application/x-shar")
MIME_TYPE(APPLICATION_SIT,		"application/stuffit")
MIME_TYPE(APPLICATION_TAR,		"application/tar")
MIME_TYPE(APPLICATION_TEX,		"application/x-tex")
MIME_TYPE(APPLICATION_TEXINFO,		"application/x-texinfo")
MIME_TYPE(APPLICATION_TROFF,		"application/x-troff")
MIME_TYPE(APPLICATION_TROFF_MAN,	"application/x-troff-man")
MIME_TYPE(APPLICATION_TROFF_ME,		"application/x-troff-me")
MIME_TYPE(APPLICATION_TROFF_MS,		"application/x-troff-ms")
MIME_TYPE(APPLICATION_ZIP,		"application/zip")
MIME_TYPE(AUDIO_BASIC,			"audio/basic")
MIME_TYPE(AUDIO_FLAC,			"audio/flac")
MIME_TYPE(AUDIO_MATROSKA,		"audio/x-matroska")
MIME_TYPE(AUDIO_MIDI,			"audio/midi")
MIME_TYPE(AUDIO_MP4,			"audio/mp4")
MIME_TYPE(AUDIO_MPEG,			"audio/mpeg")
MIME_TYPE(AUDIO_MPEGURL,		"audio/x-mpegurl")
MIME_TYPE(AUDIO_OGG,			"audio/ogg")
MIME_TYPE(AUDIO_PLAYLIST,		"audio/x-scpls")
MIME_TYPE(AUDIO_REALAUDIO,		"audio/x-realaudio")
MIME_TYPE(AUDIO_SPEEX,			"audio/x-speex")
MIME_TYPE(AUDIO_WAVE,			"audio/x-wav")
MIME_TYPE(IMAGE_BMP,			"image/bmp")
MIME_TYPE(IMAGE_GIF,			"image/gif")
MIME_TYPE(IMAGE_JPEG,			"image/jpeg")
MIME_TYPE(IMAGE_PNG,			"image/png")
MIME_TYPE(IMAGE_PSD,			"image/photoshop")
MIME_TYPE(IMAGE_TIFF,			"image/tiff")
MIME_TYPE(IMAGE_XPM,			"image/x-xpmi")
MIME_TYPE(MESSAGE_RFC822,		"message/rfc822")
MIME_TYPE(TEXT_C, 				"text/x-c")
MIME_TYPE(TEXT_CALENDAR,		"text/calendar")
MIME_TYPE(TEXT_CHDR, 			"text/x-chdr")
MIME_TYPE(TEXT_CPP, 			"text/x-c++")
MIME_TYPE(TEXT_CPPHDR, 			"text/x-c++hdr")
MIME_TYPE(TEXT_CSS, 			"text/css")
MIME_TYPE(TEXT_CSV, 			"text/csv")
MIME_TYPE(TEXT_DIFF, 			"text/x-diff")
MIME_TYPE(TEXT_HTML, 			"text/html")
MIME_TYPE(TEXT_JAVA, 			"text/x-java")
MIME_TYPE(TEXT_LATEX, 			"text/x-latex")
MIME_TYPE(TEXT_LILYPOND,		"text/x-lilypond")
MIME_TYPE(TEXT_PERL, 			"text/x-perl")
MIME_TYPE(TEXT_PLAIN, 			"text/plain")
MIME_TYPE(TEXT_PYTHON, 			"text/x-python")
MIME_TYPE(TEXT_RTF, 			"text/rtf")
MIME_TYPE(TEXT_XHTML, 			"text/xhtml")
MIME_TYPE(TEXT_XML, 			"text/xml")
MIME_TYPE(VIDEO_FLV,			"video/x-flv")
MIME_TYPE(VIDEO_MATROSKA,		"video/x-matroska")
MIME_TYPE(VIDEO_MP4,			"video/mp4")
MIME_TYPE(VIDEO_MPEG,			"video/mpeg")
MIME_TYPE(VIDEO_MSVIDEO,		"video/x-msvideo")
MIME_TYPE(VIDEO_OGG,			"video/ogg")
MIME_TYPE(VIDEO_OGM,			"video/x-ogg")
MIME_TYPE(VIDEO_QUICKTIME,		"video/quicktime")

==> gtk-gnutella_0.96.8.orig.tar.gz: gtk-gnutella-0.96.8/src/lib/mime_types.h <==
MIME_TYPE(APPLICATION_7Z, 		"application/x-7z-compressed")
MIME_TYPE(APPLICATION_ACE,		"application/x-ace-compressed")
MIME_TYPE(APPLICATION_BINARY, 		"application/binary")
MIME_TYPE(APPLICATION_BITTORRENT,	"application/x-bittorrent")
MIME_TYPE(APPLICATION_BZIP2,  		"application/x-bzip2")
MIME_TYPE(APPLICATION_COMPRESS,		"application/x-compress")
MIME_TYPE(APPLICATION_DEB,		"application/x-debian-package")
MIME_TYPE(APPLICATION_DMG,		"application/x-apple-diskimage")
MIME_TYPE(APPLICATION_DOSEXEC,		"application/x-dosexec")
MIME_TYPE(APPLICATION_EXCEL,		"application/vnd.ms-excel")
MIME_TYPE(APPLICATION_GAMEBOY_ROM,	"application/x-gameboy-rom")
MIME_TYPE(APPLICATION_GENESIS_ROM,	"application/x-genesis-rom")
MIME_TYPE(APPLICATION_GZIP,		"application/x-gzip")
MIME_TYPE(APPLICATION_ISO9660,		"application/x-iso9660-image")
MIME_TYPE(APPLICATION_JAR,		"application/x-java-archive")
MIME_TYPE(APPLICATION_JAVA,		"application/java")
MIME_TYPE(APPLICATION_JAVASCRIPT,	"application/x-javascript")
MIME_TYPE(APPLICATION_JAVA_SER,		"application/x-java-serialized-object")
MIME_TYPE(APPLICATION_JAVA_VM,		"application/x-java-vm")
MIME_TYPE(APPLICATION_LATEX,		"application/x-latex")
MIME_TYPE(APPLICATION_LYX,		"application/x-lyx")
MIME_TYPE(APPLICATION_LZH,		"application/x-lzh-compressed")
MIME_TYPE(APPLICATION_MSWORD,		"application/msword")
MIME_TYPE(APPLICATION_MS_SHORTCUT,	"application/x-ms-shortcut")
MIME_TYPE(APPLICATION_N64_ROM,		"application/x-n64-rom")
MIME_TYPE(APPLICATION_NES_ROM,		"application/x-nes-rom")
MIME_TYPE(APPLICATION_OBJECT,		"application/x-object")
MIME_TYPE(APPLICATION_OCTET_STREAM, 	"application/octet-stream")
MIME_TYPE(APPLICATION_OGG,		"application/ogg")
MIME_TYPE(APPLICATION_PDF,		"application/pdf")
MIME_TYPE(APPLICATION_POSTSCRIPT,	"application/postscript")
MIME_TYPE(APPLICATION_POWERPOINT,	"application/vnd.ms-powerpoint")
MIME_TYPE(APPLICATION_RAR,		"application/x-rar")
MIME_TYPE(APPLICATION_RDF,		"application/rss+rdf")
MIME_TYPE(APPLICATION_RPM,		"application/x-redhat-package")
MIME_TYPE(APPLICATION_RSS,		"application/rss+xml")
MIME_TYPE(APPLICATION_SH,		"application/x-sh")
MIME_TYPE(APPLICATION_SHAR,		"application/x-shar")
MIME_TYPE(APPLICATION_SHOCKWAVE_FLASH,	"application/x-shockwave-flash")
MIME_TYPE(APPLICATION_SNES_ROM,		"application/x-snes-rom")
MIME_TYPE(APPLICATION_SIT,		"application/stuffit")
MIME_TYPE(APPLICATION_TAR,		"application/tar")
MIME_TYPE(APPLICATION_TEX,		"application/x-tex")
MIME_TYPE(APPLICATION_TEXINFO,		"application/x-texinfo")
MIME_TYPE(APPLICATION_TROFF,		"application/x-troff")
MIME_TYPE(APPLICATION_TROFF_MAN,	"application/x-troff-man")
MIME_TYPE(APPLICATION_TROFF_ME,		"application/x-troff-me")
MIME_TYPE(APPLICATION_TROFF_MS,		"application/x-troff-ms")
MIME_TYPE(APPLICATION_ZIP,		"application/zip")
MIME_TYPE(AUDIO_BASIC,			"audio/basic")
MIME_TYPE(AUDIO_FLAC,			"audio/flac")
MIME_TYPE(AUDIO_MATROSKA,		"audio/x-matroska")
MIME_TYPE(AUDIO_MIDI,			"audio/midi")
MIME_TYPE(AUDIO_MP4,			"audio/mp4")
MIME_TYPE(AUDIO_MPEG,			"audio/mpeg")
MIME_TYPE(AUDIO_MPEGURL,		"audio/x-mpegurl")
MIME_TYPE(AUDIO_OGG,			"audio/ogg")
MIME_TYPE(AUDIO_PLAYLIST,		"audio/x-scpls")
MIME_TYPE(AUDIO_REALAUDIO,		"audio/x-realaudio")
MIME_TYPE(AUDIO_SPEEX,			"audio/speex")
MIME_TYPE(AUDIO_MS_ASF,			"audio/x-ms-asf")
MIME_TYPE(AUDIO_WAVE,			"audio/x-wav")
MIME_TYPE(IMAGE_BMP,			"image/bmp")
MIME_TYPE(IMAGE_GIF,			"image/gif")
MIME_TYPE(IMAGE_JPEG,			"image/jpeg")
MIME_TYPE(IMAGE_PNG,			"image/png")
MIME_TYPE(IMAGE_PSD,			"image/photoshop")
MIME_TYPE(IMAGE_TGA,			"image/x-targa")
MIME_TYPE(IMAGE_TIFF,			"image/tiff")
MIME_TYPE(IMAGE_XPM,			"image/x-xpmi")
MIME_TYPE(MESSAGE_RFC822,		"message/rfc822")
MIME_TYPE(TEXT_C, 				"text/x-c")
MIME_TYPE(TEXT_CALENDAR,		"text/calendar")
MIME_TYPE(TEXT_CHDR, 			"text/x-chdr")
MIME_TYPE(TEXT_CPP, 			"text/x-c++")
MIME_TYPE(TEXT_CPPHDR, 			"text/x-c++hdr")
MIME_TYPE(TEXT_CSS, 			"text/css")
MIME_TYPE(TEXT_CSV, 			"text/csv")
MIME_TYPE(TEXT_DIFF, 			"text/x-diff")
MIME_TYPE(TEXT_HTML, 			"text/html")
MIME_TYPE(TEXT_JAVA, 			"text/x-java")
MIME_TYPE(TEXT_LATEX, 			"text/x-latex")
MIME_TYPE(TEXT_LILYPOND,		"text/x-lilypond")
MIME_TYPE(TEXT_PERL, 			"text/x-perl")
MIME_TYPE(TEXT_PLAIN, 			"text/plain")
MIME_TYPE(TEXT_PYTHON, 			"text/x-python")
MIME_TYPE(TEXT_RTF, 			"text/rtf")
MIME_TYPE(TEXT_XHTML, 			"text/xhtml")
MIME_TYPE(TEXT_XML, 			"text/xml")
MIME_TYPE(VIDEO_FLV,			"video/x-flv")
MIME_TYPE(VIDEO_MATROSKA,		"video/x-matroska")
MIME_TYPE(VIDEO_MP4,			"video/mp4")
MIME_TYPE(VIDEO_MPEG,			"video/mpeg")
MIME_TYPE(VIDEO_MSVIDEO,		"video/x-msvideo")
MIME_TYPE(VIDEO_MS_ASF,			"video/x-ms-asf")
MIME_TYPE(VIDEO_OGG,			"video/ogg")
MIME_TYPE(VIDEO_OGM,			"video/x-ogg")
MIME_TYPE(VIDEO_QUICKTIME,		"video/quicktime")
